import React from "react";
import PropTypes from 'prop-types'
import { withTheme } from "styled-components";

import Icon from "../Icon/Component";
import Spinner from "../Spinner/Component"

import { Button_element, Button_text, Icon_Wrapper, Loading_indicator} from "./Style";

function Button(props) {
    const [focusButton, changeFocus ] = React.useState(false)

    function clickedButton(event){
      if(!props.isLoading){
          props.callBalck && props.callBalck()
      }
    }

    function keyup(event){
        if (event.keyCode === 9){
            changeFocus(true)
        }
    }

    return (
        <>
            {(props.label || props.icon) && (
                <Button_element
                    onBlur={(event) => {event.persist(); changeFocus(false)}}
                    onMouseDown={(event) => {event.persist(); changeFocus(false)}}
                    onClick={(event) => {event.persist(); clickedButton(event)}}
                    onKeyUp={(event) => {event.persist(); keyup(event)}}

                    role="button"
                    loading={props.isLoading ? 1: 0}
                    focused={focusButton}
                    label={props.label}
                    aria-label={props.label}
                    aria-disabled={props.isDisabled || props.isLoading}
                    width={props.width}
                    disabled={props.isDisabled || props.isLoading}
                    color_type={props.color}
                    kind_type={props.kind}
                    size={props.size}>

                    { props.label && (
                        <Button_text icon={props.icon} loading={props.isLoading ? 1: 0}>{props.label}</Button_text>
                    )}

                    {props.icon && props.isLoading && (
                        <Icon className="Button_icon" icon={props.icon}>
                            <Spinner color="black" thickness="4px" />
                        </Icon>
                    )}

                    {props.icon && !props.isLoading && (
                        <Icon className="Button_icon" icon={props.icon}></Icon>
                    )}

                    {!props.icon && props.label && (
                        <Loading_indicator className="Button_icon" size={props.size}>
                            <Spinner color="black" thickness="4px" />
                        </Loading_indicator>
                    )}
                </Button_element>
            )}
        </>


    )
}
Button.defaultProps = {
    label: "Button",
    icon: "",
    ariaLabel: "Button",
    color: "green",
    kind: "primary_loud",
    size: "m",
    width: "fixed",
    isLoading: false,
    isDisabled: false,
};

Button.propTypes = {
    label: PropTypes.string,
    kind: PropTypes.string,
    icon: PropTypes.string,
    size: PropTypes.string,
    color: PropTypes.string,
    width: PropTypes.string,
    ariaLabel: PropTypes.string,
    isDisabled: PropTypes.bool,
    isLoading: PropTypes.bool,
    callBack: PropTypes.func
}

export default withTheme(Button);
