import styled from "styled-components"
import { Model } from "./Model"
import Theme from "../../Themes/default";

export const Button_element = styled.button`
    border: none;
    position: relative;
    outline: none;
    display: flex;
    align-items: center;
    justify-content: space-between;
    div.Button_icon {
      display: flex;
      box-sizing: border-box;
    }
    ${({width}) => width === 'full' && `
       width: 100%;
       text-align: left;  
    `}
    
    //with label sizes
    ${({size, theme}) => size && theme && `
        font-size: ${Model(theme).size[size].font.fontSize * theme.size.atom}px;
        font-weight: ${Model(theme).size[size].font.fontWeight};
        line-height: ${Model(theme).size[size].font.lineHeight * theme.size.atom}px;
        font-family: ${theme.font.family};
               
        padding-top: ${Model(theme).size[size].button.paddingTop}px;
        padding-right: ${Model(theme).size[size].button.paddingRight}px;
        padding-bottom: ${Model(theme).size[size].button.paddingBottom}px;
        padding-left: ${Model(theme).size[size].button.paddingLeft}px;
            
        .Button_icon {
          margin-left: ${Model(theme).size[size].icon.marginLeft}px;
          margin-right: ${Model(theme).size[size].icon.marginRight}px;
          min-width: ${Model(theme).size[size].icon.width}px;
          min-height: ${Model(theme).size[size].icon.height}px;
          width: ${Model(theme).size[size].icon.width}px;
          height: ${Model(theme).size[size].icon.height}px;
          padding-top: ${Model(theme).size[size].icon.paddingTop}px;
          padding-right: ${Model(theme).size[size].icon.paddingRight}px;
          padding-bottom: ${Model(theme).size[size].icon.paddingBottom}px;
          padding-left: ${Model(theme).size[size].icon.paddingLeft}px;
        }
    `}
    
    //without label sizes
    ${({size, theme, label }) => size && theme && !label &&`        
        padding-top: ${Model(theme).size[size].onlyIcon.button.paddingTop}px;
        padding-right: ${Model(theme).size[size].onlyIcon.button.paddingRight}px;
        padding-bottom: ${Model(theme).size[size].onlyIcon.button.paddingBottom}px;
        padding-left: ${Model(theme).size[size].onlyIcon.button.paddingLeft}px;    
        .Button_icon {
          margin-left: ${Model(theme).size[size].onlyIcon.icon.marginLeft}px;
          margin-right: ${Model(theme).size[size].onlyIcon.icon.marginRight}px;
          width: ${Model(theme).size[size].onlyIcon.icon.width}px;
          height: ${Model(theme).size[size].onlyIcon.icon.height}px;
          padding-top: ${Model(theme).size[size].onlyIcon.icon.paddingTop}px;
          padding-right: ${Model(theme).size[size].onlyIcon.icon.paddingRight}px;
          padding-bottom: ${Model(theme).size[size].onlyIcon.icon.paddingBottom}px;
          padding-left: ${Model(theme).size[size].onlyIcon.icon.paddingLeft}px;
        }
    `}

    //focus style
    ${({theme, focused}) => focused && `
        outline: 4px solid ${theme.colors.Accessibility_outline};    
    `}
    
    //styles by themes
    ${({kind_type, color_type, theme}) => Model(theme).style[color_type][kind_type] && `
       color: ${Model(theme).style[color_type][kind_type].default.fontColor};
       div.Button_icon {
         svg {
           fill: ${Model(theme).style[color_type][kind_type].default.fontColor};
         }
       }
       background: ${Model(theme).style[color_type][kind_type].default.background};
       box-shadow: inset 0 0 0 1px ${Model(theme).style[color_type][kind_type].default.borderColor};
       :hover {
          cursor: pointer;
          background: ${Model(theme).style[color_type][kind_type].hover.background};
          color: ${Model(theme).style[color_type][kind_type].hover.fontColor};
          div.Button_icon {
            svg {
              fill: ${Model(theme).style[color_type][kind_type].hover.fontColor};
            }
          }
          box-shadow: inset 0 0 0 1px ${Model(theme).style[color_type][kind_type].hover.borderColor};
       }
       :active {
          background: ${Model(theme).style[color_type][kind_type].active.background};
          color: ${Model(theme).style[color_type][kind_type].active.fontColor};
          div.Button_icon {
           svg {
            fill: ${Model(theme).style[color_type][kind_type].active.fontColor};
           }
          }
          box-shadow: inset 0 0 0 1px ${Model(theme).style[color_type][kind_type].active.borderColor};
        }
        :disabled {
            opacity: 0.4;
            :hover {
                color: ${Model(theme).style[color_type][kind_type].default.fontColor};
                div.Button_icon {
                   svg {
                    fill: ${Model(theme).style[color_type][kind_type].default.fontColor};
                   }
                 }
                background: ${Model(theme).style[color_type][kind_type].default.background};
                box-shadow: inset 0 0 0 1px ${Model(theme).style[color_type][kind_type].default.borderColor};;
            }
        }
    `}

     //styles animation spinner by themes
    ${({kind_type, color_type, theme, loading}) => Model(theme).style[color_type][kind_type] && loading && `
       div.Button_icon {
         svg {
           stroke: ${Model(theme).style[color_type][kind_type].default.fontColor};
         }
       }
       :hover {
          div.Button_icon {
            svg {
              stroke: ${Model(theme).style[color_type][kind_type].hover.fontColor};
            }
          }
       }
       :active {
          div.Button_icon {
           svg {
            stroke: ${Model(theme).style[color_type][kind_type].active.fontColor};
           }
          }
        }
        :disabled {
            :hover {
                div.Button_icon {
                   svg {
                    stroke: ${Model(theme).style[color_type][kind_type].default.fontColor};
                   }
                 }
            }
        }
    `}
`;

export const Button_text = styled.span`
  overflow: hidden;
  text-overflow: ellipsis;
  ${({icon, loading}) => !icon && loading && `
    opacity: 0;
  `}
`

export const Loading_indicator = styled.div`
  position: absolute;
  margin: 0!important;
  padding: 0!important;
  ${({size, theme}) => `
     left: calc(50% - ${Model(theme).size[size].onlyIcon.icon.width / 2}px);
  `}
`

Loading_indicator.defaultProps = {
    theme: Theme,
}

Button_element.defaultProps = {
    theme: Theme,
}
