import React from "react";
import PropTypes from 'prop-types'
import { withTheme } from "styled-components";

import Icon from "../Icon/Component";

import { Checkbox_wrapper, Checkbox_input, Custom_checkbox, Label_text } from "./Style"


function Checkbox(props) {
    const [focusButton, changeFocus ] = React.useState(false)
    const [checkboxState, changeState] = React.useState(props.value)

    function keyup(event){
        if (event.keyCode === 9){
            changeFocus(true)
        }
    }
    function CheckboxChanged(){
        changeState(!checkboxState)
        props.callback && props.callback(!checkboxState)
    }

    return (
        <Checkbox_wrapper color_type={props.color}
                          selected={checkboxState ? 1 : 0}
                          inverse={props.isInverse}
                          disabled={props.isDisabled}
                          error={props.isError}
                          label={props.label}>

            <Checkbox_input type="checkbox"
                            onBlur={(event) => {event.persist(); changeFocus(false)}}
                            onMouseDown={(event) => {event.persist(); changeFocus(false)}}
                            onKeyUp={(event) => {event.persist(); keyup(event)}}

                            aria-checked={checkboxState}
                            aria-disabled={props.isDisabled}
                            aria-label={props.ariaLabel}

                            checked={checkboxState}
                            disabled={props.isDisabled}
                            onChange={(event) => {event.persist(); CheckboxChanged(event)}}/>

            <Custom_checkbox className="custom_checkbox" focused={focusButton}>
                <Icon className="checkbox_icon" icon={props.isIndeterminate ? "minus_16" : "check_16"}></Icon>
            </Custom_checkbox>

            <Label_text className="label_text">{props.label}</Label_text>
        </Checkbox_wrapper>
    )
}

Checkbox.defaultProps = {
    label: "Label",
    ariaLabel: "Label",
    color: "green",
    value: false,
    isInverse: false,
    isError: false,
    isDisabled: false,
    isIndeterminate: false,
    changeState: () => false
};

Checkbox.propTypes = {
    label: PropTypes.string,
    ariaLabel: PropTypes.string,
    color: PropTypes.string,
    value: PropTypes.bool,
    isInverse: PropTypes.bool,
    isError: PropTypes.bool,
    isDisabled: PropTypes.bool,
    isIndeterminate: PropTypes.bool,
    changeState: PropTypes.func
}

export default withTheme(Checkbox);
