import styled from "styled-components"
import { Model } from "./Model"
import Theme from "../../Themes/default";


function StyleCheckbox(background, borderColor, iconColor, fontColor, disabled){

  if(disabled){
      return `
        .custom_checkbox {
          background-color: ${background.default};
          box-shadow: inset 0 0 0 1px ${borderColor.default};
        }
        .label_text {
          color: ${fontColor.default};
        }
        svg {
          fill: ${iconColor.default}; 
        }
      `
  }else{
      return `
            .custom_checkbox {
              background-color: ${background.default};
              box-shadow: inset 0 0 0 1px ${borderColor.default};
            }
            .label_text {
              color: ${fontColor.default};
            }
            svg {
              fill: ${iconColor.default}; 
            }
            :hover {
              .custom_checkbox {
                background-color: ${background.hover};
                box-shadow: inset 0 0 0 1px ${borderColor.hover};
              }
              .label_text {
                color: ${fontColor.hover};
              }
              svg {
                fill: ${iconColor.hover}; 
              }
            }
          `
        }
}

export const Checkbox_wrapper = styled.label`
  ${({theme}) => `
    height: ${theme.size.atom * 4}px;
    display: flex;
    cursor: pointer; 
  `}
  
  ${({disabled}) => disabled && `
    opacity: 0.4;
    cursor: default;
  `}
  
  ${({label, theme}) => !label && `
    display: inline-block;
    height: ${theme.size.atom * 4}px;
    width: ${theme.size.atom * 4}px;
  `}
  
  //deselected
  ${({theme, color_type, disabled}) => StyleCheckbox(
      {
        default: Model(theme).style[color_type].default.background,
        hover:  Model(theme).style[color_type].hover.background,
      },
      {
        default: Model(theme).style[color_type].default.borderColor,
        hover:  Model(theme).style[color_type].hover.borderColor,
      },
      {
        default: Model(theme).style[color_type].default.iconColor,
        hover:  Model(theme).style[color_type].hover.iconColor,
      },
      {
        default: Model(theme).style[color_type].default.fontColor,
        hover:  Model(theme).style[color_type].hover.fontColor,
      },
      disabled
  )}

  //selected with colors
  ${({theme, selected, color_type, disabled}) => selected && StyleCheckbox(
      {
        default: Model(theme).style[color_type].selected.background,
        hover:  Model(theme).style[color_type].hover_selected.background,
      },
      {
        default: Model(theme).style[color_type].selected.borderColor,
        hover:  Model(theme).style[color_type].hover_selected.borderColor,
      },
      {
        default: Model(theme).style[color_type].selected.iconColor,
        hover:  Model(theme).style[color_type].hover_selected.iconColor,
      },{
        default: Model(theme).style[color_type].selected.fontColor,
        hover:  Model(theme).style[color_type].hover_selected.fontColor,
      },
      disabled    
  )}

    //inverse deselected
  ${({theme, inverse, error, disabled}) => inverse && !error && StyleCheckbox(
      {
        default: Model(theme).style.inverse.default.background,
        hover:  Model(theme).style.inverse.hover.background,
      },
      {
        default: Model(theme).style.inverse.default.borderColor,
        hover:  Model(theme).style.inverse.hover.borderColor,
      },
      {
        default: Model(theme).style.inverse.default.iconColor,
        hover:  Model(theme).style.inverse.hover.iconColor,
      },{
        default: Model(theme).style.inverse.default.fontColor,
        hover:  Model(theme).style.inverse.hover.fontColor,
      },
      disabled
  )}

    //inverse selected
  ${({theme, inverse, selected, error, disabled}) => inverse && selected && !error && StyleCheckbox(
      {
        default: Model(theme).style.inverse.selected.background,
        hover:  Model(theme).style.inverse.hover_selected.background,
      },
      {
        default: Model(theme).style.inverse.selected.borderColor,
        hover:  Model(theme).style.inverse.hover_selected.borderColor,
      },
      {
        default: Model(theme).style.inverse.selected.iconColor,
        hover:  Model(theme).style.inverse.hover_selected.iconColor,
      },
      {
        default: Model(theme).style.inverse.selected.fontColor,
        hover:  Model(theme).style.inverse.hover_selected.fontColor,
      },
      disabled
  )}

    //error deselected
  ${({theme, error, selected, disabled}) => selected === 0 && error && StyleCheckbox(
      {
        default: Model(theme).style.error.default.background,
        hover:  Model(theme).style.error.hover.background,
      },
      {
        default: Model(theme).style.error.default.borderColor,
        hover:  Model(theme).style.error.hover.borderColor,
      },
      {
        default: Model(theme).style.error.default.iconColor,
        hover:  Model(theme).style.error.hover.iconColor,
      },
      {
        default: Model(theme).style.error.default.fontColor,
        hover:  Model(theme).style.error.hover.fontColor,
      },
      disabled
  )}

    //selected error
  ${({theme, selected, error, disabled}) => selected && error && StyleCheckbox(
      {
        default: Model(theme).style.error.selected.background,
        hover:  Model(theme).style.error.hover_selected.background,
      },
      {
        default: Model(theme).style.error.selected.borderColor,
        hover:  Model(theme).style.error.hover_selected.borderColor,
      },
      {
        default: Model(theme).style.error.selected.iconColor,
        hover:  Model(theme).style.error.hover_selected.iconColor,
      },
      {
        default: Model(theme).style.error.selected.fontColor,
        hover:  Model(theme).style.error.hover_selected.fontColor,
      },
      disabled 
  )}

    //selected error inverse
  ${({theme, selected, error, inverse, disabled}) => selected && error && inverse && StyleCheckbox(
      {
        default: Model(theme).style.error_inverse.selected.background,
        hover:  Model(theme).style.error_inverse.hover_selected.background,
      },
      {
        default: Model(theme).style.error_inverse.selected.borderColor,
        hover:  Model(theme).style.error_inverse.hover_selected.borderColor,
      },
      {
        default: Model(theme).style.error_inverse.selected.iconColor,
        hover:  Model(theme).style.error_inverse.hover_selected.iconColor,
      },
      {
        default: Model(theme).style.error_inverse.selected.fontColor,
        hover:  Model(theme).style.error_inverse.hover_selected.fontColor,
      },
      disabled
  )}
`

export const Checkbox_input = styled.input`
  position: absolute;
  opacity: 0;
`

export const Custom_checkbox = styled.div`
    display: block;
    box-sizing: border-box;
    div.checkbox_icon {
      display: flex;
      align-items: center;
      justify-content: center;
      width: 100%;
      height: 100%;
    }
  ${({theme}) => `
    width: ${theme.size.atom * 4}px;
    height: ${theme.size.atom * 4}px;
    min-width: ${theme.size.atom * 4}px;
    min-height: ${theme.size.atom * 4}px;
    svg {
      width: ${theme.size.atom * 2.5}px;
      height: ${theme.size.atom * 2.5}px;
    }
  `}
  ${({focused, theme}) => focused && `
    outline: 2px solid ${theme.colors.Accessibility_outline};    
  `}
`

export const Label_text = styled.span`
  position: relative;
  ${({theme}) => `
    top: -${theme.size.atom * 0.75}px;
    margin-left: ${theme.size.atom * 2}px;
    font-size: ${Model(theme).font.fontSize * theme.size.atom}px;
    font-weight: ${Model(theme).font.fontWeight};
    line-height: ${Model(theme).font.lineHeight * theme.size.atom}px;
    font-family: ${theme.font.family};
  `}
`

Checkbox_wrapper.defaultProps = {
  theme: Theme,
}

Checkbox_input.defaultProps = {
  theme: Theme,
}

Custom_checkbox.defaultProps = {
  theme: Theme,
}

Label_text.defaultProps = {
  theme: Theme,
}
